from .main import get_nfw_gc,get_dehnen_core_gc,get_dehnen_cusp_gc,get_nfw_scale,get_dehnen_core_scale,get_dehnen_cusp_scale,get_abg_triangle_scale,nfw_mass_density,dehnen_core_mass_density,dehnen_cusp_mass_density,nfw_enclosed_mass,dehnen_core_enclosed_mass,dehnen_cusp_enclosed_mass,fncore,cnfw_mass_density,cnfw_enclosed_mass,cnfwt_mass_density,cnfwt_enclosed_mass,abg_triangle_mass_density,abg_triangle_enclosed_mass,get_plum_scale,get_exp_scale,get_sersic_scale,get_a2bg_scale,get_abg_scale,plum_luminosity_density,plum_luminosity_density_2d,sersic_luminosity_density,exp_luminosity_density,sersic_luminosity_density_2d,exp_luminosity_density_2d,a2bg_luminosity_density,a2bg_luminosity_density_2d,abg_luminosity_density,abg_luminosity_density_2d,plum_enclosed_luminosity,sersic_enclosed_luminosity,exp_enclosed_luminosity,a2bg_enclosed_luminosity,abg_enclosed_luminosity,plum_lscalenorm,sersic_lscalenorm,exp_lscalenorm,a2bg_lscalenorm,abg_lscalenorm,plum_ltotnorm,sersic_ltotnorm,exp_ltotnorm,a2bg_ltotnorm,abg_ltotnorm,get_dmhalo,get_tracer,get_anisotropy,get_rhalf,integrate,integrate_isotropic,projected_virial,get_virial



import main as jeans
import numpy as np

alpha=2.
beta=5.
gamma=0.
luminosity_tot=1.
r_scale=1.

shite=jeans.get_tracer('abg',r_scale=1.,alpha=2.,beta=5.,gamma=0.,luminosity_tot=1.,upsilon=1.)
np.pause()
xxx=0.5
shite=jeans.abg_luminosity_density_2d(xxx,alpha,beta,gamma)
scale=jeans.get_abg_scale(luminosity_tot,r_scale,alpha,beta,gamma)

boober1=shite*scale[1]
print(boober1)
piss=jeans.plum_luminosity_density_2d(xxx)
scale2=jeans.get_plum_scale(luminosity_tot,r_scale)
boober2=piss*scale2[1]
print(boober2)
print(boober2/boober1)
